@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package namespace::autoclean;
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # ABSTRACT: Keep imports out of your namespace
 
@@ -38,7 +38,8 @@ sub import {
 
     on_scope_end {
         my $meta = Class::MOP::Class->initialize($cleanee);
-        my %methods = map { ($_ => 1) } keys %{ $meta->get_method_map };
+        my %methods = map { ($_ => 1) } $meta->get_method_list;
+        $methods{meta} = 1 if $meta->isa('Moose::Meta::Role') && Moose->VERSION < 0.90;
         my %extra = ();
 
         for my $method (keys %methods) {
@@ -55,13 +56,16 @@ sub import {
 1;
 
 __END__
+
+=pod
+
 =head1 NAME
 
 namespace::autoclean - Keep imports out of your namespace
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -87,7 +91,7 @@ class or instances.
 
 This module is very similar to L<namespace::clean|namespace::clean>, except it
 will clean all imported functions, no matter if you imported them before or
-after you C<use>d the pagma. It will also not touch anything that looks like a
+after you C<use>d the pragma. It will also not touch anything that looks like a
 method, according to C<Class::MOP::Class::get_method_list>.
 
 If you're writing an exporter and you want to clean up after yourself (and your
@@ -104,17 +108,6 @@ peers), you can use the C<-cleanee> switch to specify what package to clean:
       );
   }
 
-=head1 AUTHOR
-
-  Florian Ragwitz <rafl@debian.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2009 by Florian Ragwitz.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 PARAMETERS
 
 =head2 -also => [ ITEM | REGEX | SUB, .. ]
@@ -157,3 +150,19 @@ L<Class::MOP>
 
 L<B::Hooks::EndOfScope>
 
+
+
+=head1 AUTHOR
+
+  Florian Ragwitz <rafl@debian.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Florian Ragwitz.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
+
+
